@@ -21,6 +21,7 @@ from json import dumps as json_dumps
 from typing import Any
 
 import aiohttp
+
 from hydroqc.error import HydroQcError, HydroQcHTTPError
 from hydroqc.hydro_api.cache import CCached
 from hydroqc.hydro_api.consts import (
@@ -39,6 +40,7 @@ from hydroqc.hydro_api.consts import (
     HOURLY_CONSUMPTION_API_URL,
     LOGIN_URL_6,
     MONTHLY_DATA_URL,
+    OUTAGES,
     PERIOD_DATA_URL,
     PORTRAIT_URL,
     RELATION_URL,
@@ -48,8 +50,6 @@ from hydroqc.hydro_api.consts import (
     SESSION_URL,
 )
 from hydroqc.logger import get_logger
-from hydroqc.winter_credit.consts import EST_TIMEZONE
-
 from hydroqc.types import (
     ComptesTyping,
     ConsoAnnualTyping,
@@ -62,11 +62,13 @@ from hydroqc.types import (
     IDTokenTyping,
     InfoCompteTyping,
     ListContractsTyping,
+    OutageListTyping,
     PeriodDataTyping,
     WinterCreditDataTyping,
     listeComptesContratsTyping,
     listeContratModelTyping,
 )
+from hydroqc.utils import EST_TIMEZONE
 
 
 class HydroClient:
@@ -114,11 +116,13 @@ class HydroClient:
         """Get http client user_agent."""
         try:
             hydroqc_version = version("Hydro_Quebec_API_Wrapper")
-        except PackageNotFoundError as exp:
+        except PackageNotFoundError:
             # package is not installed
-            raise HydroQcHTTPError(
-                "Python package `Hydro_Quebec_API_Wrapper` is not installed. Install it using pip"
-            ) from exp
+            self._logger.warning(
+                "Python package `Hydro_Quebec_API_Wrapper` is not installed. "
+                "Install it using pip"
+            )
+            hydroqc_version = "unkwown"
         os_name = platform.system()
         return f"Hydroqc/{hydroqc_version} (dev@hydroqc.ca; https://gitlab.com/hydroqc) {os_name}"
 
@@ -572,6 +576,15 @@ class HydroClient:
         data: WinterCreditDataTyping = await api_call_response.json()
         return data
 
+    @CCached(ttl=900)
+    async def get_outages(
+        self, consumption_location_id: str
+    ) -> OutageListTyping | None:
+        """Return outages for a given consumption location id."""
+        response = await self.http_request(OUTAGES + consumption_location_id, "get")
+        res: list[OutageListTyping] = await response.json()
+        return res[0] if res else None
+
     async def get_today_hourly_consumption(
         self, applicant_id: str, customer_id: str, contract_id: str
     ) -> ConsoHourlyTyping:
