@@ -1,38 +1,18 @@
 """Winter credit processing."""
 import datetime
 import logging
-from collections.abc import Callable
-from typing import Any
 
+from hydroqc import utils
 from hydroqc.error import HydroQcWinterCreditError
 from hydroqc.hydro_api.client import HydroClient
+from hydroqc.types import CriticalPeakDataTyping, WinterCreditDataTyping
 from hydroqc.winter_credit.consts import (
     DEFAULT_EVENING_PEAK_START,
     DEFAULT_MORNING_PEAK_START,
     DEFAULT_PRE_HEAT_DURATION,
-    EST_TIMEZONE,
 )
 from hydroqc.winter_credit.peak import Anchor, Peak
 
-from hydroqc.types import CriticalPeakDataTyping, WinterCreditDataTyping
-
-
-def winter_credit_enabled(func: Callable[..., Any]) -> Callable[..., Any]:
-    """Decorate any methods that use self.data to avoid useless calls."""
-
-    def myfunction(self: "WinterCreditHandler") -> Any | None:
-        if self.is_enabled:
-            return func(self)
-        self._logger.info("Winter credit not enabled.")
-        return None
-
-    return myfunction
-
-
-def _now() -> datetime.datetime:
-    """Get EST localized now datetime."""
-    return EST_TIMEZONE.localize(datetime.datetime.now())
-
 
 class WinterCreditHandler:
     """Winter Credit extra logic.
@@ -78,15 +58,6 @@ class WinterCreditHandler:
         """Get contract id."""
         return self._no_contrat
 
-    @property
-    def is_enabled(self) -> bool:
-        """Is winter credit mode actived."""
-        return self._is_enabled
-
-    def set_enabled(self, state: bool) -> None:
-        """Set is_enabled flag."""
-        self._is_enabled = state
-
     def set_preheat_duration(self, duration: int) -> None:
         """Set preheat duration in minutes."""
         self._preheat_duration = duration
@@ -143,7 +114,6 @@ class WinterCreditHandler:
 
     # general data
     @property
-    @winter_credit_enabled
     def winter_start_date(self) -> datetime.datetime:
         """Get start date of the winter credits."""
         if not self._raw_data["periodesEffacementsHivers"]:
@@ -164,7 +134,6 @@ class WinterCreditHandler:
         )
 
     @property
-    @winter_credit_enabled
     def winter_end_date(self) -> datetime.datetime:
         """Get end date of the winter credits."""
         if not self._raw_data["periodesEffacementsHivers"]:
@@ -185,9 +154,13 @@ class WinterCreditHandler:
         )
 
     @property
-    @winter_credit_enabled
     def cumulated_credit(self) -> float:
         """Get cumulated credits."""
+        return round(sum(p["montantEffacee"] for p in self._raw_critical_peaks), 2)
+
+    @property
+    def projected_cumulated_credit(self) -> float:
+        """Get projected_cumulated credits."""
         if self._raw_data["montantEffaceProjete"] == "":
             return 0.0
         try:
@@ -197,7 +170,6 @@ class WinterCreditHandler:
 
     # Peaks data
     @property
-    @winter_credit_enabled
     def peaks(self) -> list[Peak]:
         """List all peaks of the current winter."""
         return self._get_peaks()
@@ -226,27 +198,24 @@ class WinterCreditHandler:
         return peak_list
 
     @property
-    @winter_credit_enabled
     def sonic(self) -> list[Peak]:
         """Piaf's joke."""
         return self._get_peaks()
 
     @property
-    @winter_credit_enabled
     def critical_peaks(self) -> list[Peak]:
         """Get all critical peaks of the current credits."""
         return [p for p in self.peaks if p.is_critical]
 
     # Current peak
     @property
-    @winter_credit_enabled
     def current_peak(self) -> Peak | None:
         """Get current peak.
 
         Return None if no peak is currently running
         FIXME This could be USELESS
         """
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [p for p in self.peaks if p.start_date < now < p.end_date]
         if len(peaks) > 1:
             raise HydroQcWinterCreditError("There is more than one current peak !")
@@ -255,7 +224,6 @@ class WinterCreditHandler:
         return None
 
     @property
-    @winter_credit_enabled
     def current_peak_is_critical(self) -> bool | None:
         """Return True if the current peak is critical."""
         if self.current_peak:
@@ -264,14 +232,13 @@ class WinterCreditHandler:
 
     # In progress
     @property
-    @winter_credit_enabled
     def current_state(self) -> str:
         """Get the current state of the winter credit handler.
 
         It returns critical_anchor, anchor, critical_peak, peak or normal
         This value should help for automation.
         """
-        now = _now()
+        now = utils.now()
         current_anchors = [
             p.anchor
             for p in self.peaks
@@ -290,20 +257,18 @@ class WinterCreditHandler:
         return "normal"
 
     @property
-    @winter_credit_enabled
     def preheat_in_progress(self) -> bool:
         """Get the preheat state.
 
         Returns True if we have a preheat period is in progress.
         """
-        now = _now()
+        now = utils.now()
         if self.next_peak is None:
             return False
         return self.next_peak.preheat.start_date < now < self.next_peak.preheat.end_date
 
     # Upcoming
     @property
-    @winter_credit_enabled
     def is_any_critical_peak_coming(self) -> bool:
         """Get critical state of the upcoming events.
 
@@ -315,14 +280,13 @@ class WinterCreditHandler:
 
     # Next peak
     @property
-    @winter_credit_enabled
     def next_peak(self) -> Peak | None:
         """Get next peak or current peak."""
         return self._get_next_peak()
 
     def _get_next_peak(self) -> Peak | None:
         """Get next peak or current peak."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [p for p in self.peaks if now < p.end_date]
         if not peaks:  # pylint: disable=consider-using-assignment-expr
             return None
@@ -330,7 +294,6 @@ class WinterCreditHandler:
         return next_peak
 
     @property
-    @winter_credit_enabled
     def next_peak_is_critical(self) -> bool:
         """Return True if the following next peak is critical.
 
@@ -350,10 +313,9 @@ class WinterCreditHandler:
         return next_peak.is_critical
 
     @property
-    @winter_credit_enabled
     def next_critical_peak(self) -> Peak | None:
         """Get next peak or current peak."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [p for p in self.critical_peaks if now < p.end_date]
         if not peaks:  # pylint: disable=consider-using-assignment-expr
             return None
@@ -362,10 +324,9 @@ class WinterCreditHandler:
 
     # Today peaks
     @property
-    @winter_credit_enabled
     def today_morning_peak(self) -> Peak | None:
         """Get the peak of today morning."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p for p in self.peaks if p.day == now.date() and p.is_morning
         ]
@@ -378,10 +339,9 @@ class WinterCreditHandler:
         return None
 
     @property
-    @winter_credit_enabled
     def today_evening_peak(self) -> Peak | None:
         """Get the peak of today evening."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p for p in self.peaks if p.day == now.date() and p.is_evening
         ]
@@ -395,10 +355,9 @@ class WinterCreditHandler:
 
     # Tomorrow Peaks
     @property
-    @winter_credit_enabled
     def tomorrow_morning_peak(self) -> Peak | None:
         """Get the peak of tomorrow morning."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p
             for p in self.peaks
@@ -413,10 +372,9 @@ class WinterCreditHandler:
         return None
 
     @property
-    @winter_credit_enabled
     def tomorrow_evening_peak(self) -> Peak | None:
         """Get the peak of tomorrow evening."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p
             for p in self.peaks
@@ -432,10 +390,9 @@ class WinterCreditHandler:
 
     # Yesterday peaks
     @property
-    @winter_credit_enabled
     def yesterday_morning_peak(self) -> Peak | None:
         """Get the peak of yesterday morning."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p
             for p in self.peaks
@@ -450,10 +407,9 @@ class WinterCreditHandler:
         return None
 
     @property
-    @winter_credit_enabled
     def yesterday_evening_peak(self) -> Peak | None:
         """Get the peak of yesterday evening."""
-        now = _now()
+        now = utils.now()
         peaks: list[Peak] = [
             p
             for p in self.peaks
@@ -469,10 +425,9 @@ class WinterCreditHandler:
 
     # Anchors
     @property
-    @winter_credit_enabled
     def next_anchor(self) -> Anchor | None:
         """Next or current anchor."""
-        now = _now()
+        now = utils.now()
         anchors: list[Anchor] = [
             p.anchor for p in self.peaks if now < p.anchor.end_date
         ]
